

import javax.swing.JOptionPane;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

/**
 * Ant custom task used to show a dialog box.
 */
public class DialogBoxTask extends Task {
	/**
	 * The message displayed in the dialog. 
	 */
	private String message;

	/**
	 * The dialog title.
	 */
	private String title = "Question";

	/**
	 * The type of the dialog.
	 */
	private int optionType = -1;

	/**
	 * The name of the property where the response from the dialog is saved. 
	 */
	private String propertyName;

	/**
	 * Constructor.
	 */
	public DialogBoxTask() {
		try {
			javax.swing.UIManager.setLookAndFeel(
					new com.sun.java.swing.plaf.windows.WindowsLookAndFeel());
		} catch (Exception ex) {
			// Not a tragedy.
		}
	}

	/**
	 * Set the dialog title.
	 * 
	 * @param title The totle of the dialog.
	 */
	public void setTitle(String title) {
		this.title = title;
	}

	/**
	 * Set the name of the property where the response of the dialog will be saved.
	 * 
	 * @param propertyName The property name.
	 */
	public void setProperty(String propertyName) {
		this.propertyName = propertyName;
	}

	/**
	 * Set the type of the dialog. 
	 * 
	 * @param ot The type of the dialog.
	 */
	public void setOptiontype(OptionType ot) {
		switch (ot) {
		case OK:
			optionType = -1;
			break;
		case OK_CANCEL:
			optionType = JOptionPane.OK_CANCEL_OPTION;
			break;
		case YES_NO:
			optionType = JOptionPane.YES_NO_OPTION;
			break;
		case YES_NO_CANCEL:
			optionType = JOptionPane.YES_NO_CANCEL_OPTION;
			break;
		default:
			optionType = -1;
			break;

		}
	}

	/**
	 * Set the message that will be displayed in the dialog.
	 * 
	 * @param msg The message.
	 */
	public void setMessage(String msg) {
		message = msg;
	}

	/**
	 * Executes the custom task, shows the dialog.
	 * 
	 * @see org.apache.tools.ant.Task#execute()
	 */
	public void execute() throws BuildException {
		validateAttributes();

		if (optionType == -1) {
			JOptionPane.showMessageDialog(null, // parent
					message, title, JOptionPane.INFORMATION_MESSAGE);
		} else {
			int response = JOptionPane.showConfirmDialog(null, // parent
					message, title, optionType, JOptionPane.QUESTION_MESSAGE);
			
			if (propertyName != null) {
				getProject().setProperty(propertyName, getResponseCode(response));
			}
		}
	}

	/**
	 * Check that the attributes are correct.
	 */
	protected void validateAttributes() {
		if (message == null) {
			throw new BuildException("Message must be specified using the "
					+ "message attribute or nested text.");
		}

		if (optionType == -1 && propertyName != null) {
			throw new BuildException(
					"Cannot specify property unless optionType is "
							+ "'OK_CANCEL', 'YES_NO', or 'YES_NO_CANCEL'");
		}
	}

	/**
	 * The type of the dialog.
	 */
	public static enum OptionType  {
		OK,
		OK_CANCEL,
		YES_NO,
		YES_NO_CANCEL
	}

	/**
	 * Convert the response code to a string. 
	 * 
	 * @param optionPaneResponse The response from the dialog.
	 * @return The response code as string.
	 */
	private String getResponseCode(int optionPaneResponse) {
		switch (optionPaneResponse) {
		case JOptionPane.YES_OPTION:
			return "true";
		case JOptionPane.NO_OPTION:
			return "false";
		case JOptionPane.CANCEL_OPTION:
		case JOptionPane.CLOSED_OPTION:
			return "cancel";
		default:
			throw new BuildException("Internal error: Unknown option "
					+ "pane response: " + optionPaneResponse);
		}
	}
}