<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xs" version="2.0"
  xmlns:f="myFunction">
  <xsl:output indent="yes" method="xml"/>
  <xsl:template match="/person">
      <xsl:variable name="personName">
        <xsl:variable name="givenName" select="./name/given/text()" as="xs:string"/>
        <xsl:variable name="familyName" select="./name/family/text()" as="xs:string"/>
        <xsl:value-of select="concat($givenName, ' ', $familyName)"/>
      </xsl:variable>
      <html xmlns="http://www.w3.org/1999/xhtml">
        <head>
          <title>
            <xsl:value-of select="$personName"/>
          </title>
          <link rel="stylesheet" type="text/css" href="../css/person.css"/>
        </head>
        <body>
          <table>
            <tbody>
              <tr>
                <td colspan="4">
                  <xsl:element name="img">
                    <xsl:attribute name="src" select="concat('../', @photo)"/>
                    <xsl:attribute name="alt" select="$personName"/>
                  </xsl:element>
                </td>
                <td>
                  <table>
                    <tbody class="person">
                      <tr class="name">
                        <td colspan="2">
                          <xsl:value-of select="$personName"/>
                        </td>
                      </tr>
                      <tr class="info">
                        <td class="label">Email</td>
                        <td>
                          <xsl:element name="a">
                            <xsl:variable name="emailAddr" select="./email/text()" as="xs:string"/>
                            <xsl:attribute name="href" select="concat('emailto:', $emailAddr)"/>
                            <xsl:attribute name="class">link</xsl:attribute>
                            <xsl:value-of select="$emailAddr"/>
                          </xsl:element>
                        </td>
                      </tr>
                      <tr class="info">
                        <xsl:choose>
                          <xsl:when test="link/@subordinates">
                            <td class="label">Subordinates</td>
                            <td>
                              <xsl:variable name="subordinates" select="link/@subordinates"/>
                              <xsl:variable name="currentPerson" select="." as="node()"/>
                              <xsl:for-each select="tokenize($subordinates, ' ')">
                                <xsl:variable name="cId" select="." as="xs:string"/>
                                <xsl:variable name="subord" select="f:getPerson($cId, $currentPerson)" as="node()"/>
                                <p class="inline">
                                  <xsl:element name="a">
                                    <xsl:attribute name="class">link</xsl:attribute>
                                    <xsl:attribute name="target">info</xsl:attribute>
                                    <xsl:variable name="subordPath"
                                      select="concat($subord/@id,'.html')" as="xs:string"/>
                                    <xsl:attribute name="href" select="$subordPath"/>
                                    <xsl:value-of
                                      select="concat($subord/name/given/text(), ' ', $subord/name/family/text())"
                                    />
                                  </xsl:element>
                                </p>
                              </xsl:for-each>
                            </td>
                          </xsl:when>
                          <xsl:otherwise>
                            <td class="label">Manager</td>
                            <td>
                              <xsl:variable name="managerID" select="link/@manager"/>
                              <p class="inline">
                                <xsl:element name="a">
                                  <xsl:variable name="manager" select="f:getPerson($managerID, .)" as="node()"/>
                                  <xsl:attribute name="class">link</xsl:attribute>
                                  <xsl:attribute name="target">info</xsl:attribute>
                                  <xsl:attribute name="href" select="concat($manager/@id,'.html')"/>
                                  <xsl:value-of
                                    select="concat($manager/name/given/text(), ' ', $manager/name/family/text())"
                                  />
                                </xsl:element>
                              </p>
                            </td>
                          </xsl:otherwise>
                        </xsl:choose>
                      </tr>
                      <tr class="info">
                        <td class="label">Homepage</td>
                        <td>
                          <xsl:element name="a">
                            <xsl:attribute name="class">link</xsl:attribute>
                            <xsl:attribute name="href" select="url/@href"/>
                            <xsl:value-of select="url/@href"/>
                          </xsl:element>
                        </td>
                      </tr>
                    </tbody>
                  </table>
                </td>
              </tr>
            </tbody>
          </table>
        </body>
      </html>
  </xsl:template>
  
  <xsl:function name="f:getPerson" as="node()">
    <xsl:param name="personID" as="xs:string"/>
    <xsl:param name="cNode" as="node()"/>
    
    <xsl:variable name="personIndex" select="document('../personal.xml', $cNode)"/>
    <xsl:variable name="person" select="$personIndex//person[@id=$personID]"/>
    <xsl:variable name="toReturn" select="document($person/@href, $person)"/>
    <xsl:sequence select="$toReturn/person"/>
  </xsl:function>

</xsl:stylesheet>
